==> geeklog-1.8.2-jp-extended-1.0.zip: geeklog-1.8.2-jp-extended-1.0/plugins/spamx/language/spanish.php <==
<?php

/**
 * File: spanish.php
 * This is the Spanish language page for the Geeklog Spam-X Plug-in!
 * 
 * Copyright (C) 2004-2005 by the following authors:
 * Author        Tom Willett        tomw AT pigstye DOT net
 * 
 * Licensed under GNU General Public License
 *
 * $Id: spanish.php,v 1.9 2008/05/02 15:08:10 dhaun Exp $
 */

global $LANG32;

$LANG_SX00 = array(
    'inst1' => '<p>Si haces esto, los dems ',
    'inst2' => 'podrn ver e importar tu lista negra personal y nosotros podemos crear una base de datos ',
    'inst3' => 'distribuida ms eficaz.</p><p>Si has registrado tu sitio web y decides que no deseas permanecer en la lista ',
    'inst4' => 'enva un correo electrnico a <a href="mailto:spamx@pigstye.net">spamx@pigstye.net</a> para comunicrmelo. ',
    'inst5' => 'Todas las peticiones sern respetadas.',
    'submit' => 'Enviar',
    'subthis' => 'esta informacin a la base de datos de Spam-X Central Database',
    'secbut' => 'Este botn segundo crea una fuente rdf para que otras personas puedan importar tu lista.',
    'sitename' => 'Nombre del Sitio: ',
    'URL' => 'URL a la lista de Spam-X: ',
    'RDF' => 'RDF url: ',
    'impinst1a' => 'Antes de usar la caracterstica de bloqueo de Spam con el comentario de Spam-X para ver e importar Listas negras personales de otros ',
    'impinst1b' => ' sitios, te pido que pulses sobre los siguientes dos botones. (Tienes que pulsar sobre el ltimo.)',
    'impinst2' => 'Este primero enva tu sitio web al sitio Gplugs/Spam-X para que pueda aadirse al listado principal de ',
    'impinst2a' => 'sitios que comparten sus listas negras. (Nota: Si tienes varios sitios puede que te interese designar uno de ellos como el ',
    'impinst2b' => 'principal y slo  incluir su nombre. Esto te permitir actualizar tus sitios con facilidad y mantener una lista ms pequea.) ',
    'impinst2c' => 'Despus de pulsar sobre el botn de Enviar, pulsa sobre [atrs]en tu navegador para volver aqu.',
    'impinst3' => 'Se enviarn los siguientes valores: (puedes editarlos si estn equivocados).',
    'availb' => 'Listas Negras Disponibles',
    'clickv' => 'Cliquea para ver la Lista Negra',
    'clicki' => 'Cliquea para Importar la Lista Negra',
    'ok' => 'OK',
    'rsscreated' => 'Se cre la fuente RSS',
    'add1' => 'Se han Aadido ',
    'add2' => ' datos desde ',
    'add3' => 'la lista negra de  .',
    'adminc' => 'Comandos de Administracin:',
    'mblack' => 'Mi Lista Negra:',
    'rlinks' => 'Enlaces Relacionados:',
    'e3' => 'Para aadir las palabras desde la lista de palabras censuradas de Geeklogs CensorList Pulsa el Botn:',
    'addcen' => 'Aadir Lista de Palabras Censuradas',
    'addentry' => 'Aadir dato',
    'e1' => 'Para Borrar el dato cliqualo.',
    'e2' => 'Para Aadir un dato, introdcelo en la caja y pulsa sobre Aadir.  Los datos pueden presentarse con Expresiones Normales de Perl.',
    'pblack' => 'Lista Negra Personal de Spam-X',
    'conmod' => 'Configurar el uso del mdulo de Spam-X',
    'acmod' => 'Mdulos de Accin de Spam-X',
    'exmod' => 'Mdulos de Examen de Spam-X',
    'actmod' => 'Mdulos Activos',
    'avmod' => 'Mdulos Disponibles',
    'coninst' => '<hr' . XHTML . '>Cliquea sobre un Mdulo Activo para borrarlo, cliquea sobre un mdulo Disponible para aadirlo.<br' . XHTML . '>Los mdulos se ejecutan en el orden en que han sido presentados.',
    'fsc' => 'Encontrado un comentario de Spam coincidente',
    'fsc1' => ' enviado por el usuario ',
    'fsc2' => ' desde el IP ',
    'uMTlist' => 'Actualizar la Lista Negra-MT',
    'uMTlist2' => ': Aadidas ',
    'uMTlist3' => ' entradas y borradas ',
    'entries' => ' entradas.',
    'uPlist' => 'Actualizar la Lista Negra Personal',
    'entriesadded' => 'Entradas Aadidas',
    'entriesdeleted' => 'Entradas Borradas',
    'viewlog' => 'Ver el registro de Spam-X',
    'clearlog' => 'Limpiar el fichero de Registros',
    'logcleared' => '- Fichero de Registros limpiado',
    'plugin' => 'Plugin',
    'access_denied' => 'Acceso Denegado',
    'access_denied_msg' => 'Slo los Usuarios Raz tiene Acceso a esta pgina.  Tu nombre de usuario y direccin IP han sido registrados.',
    'admin' => 'Plugin de Administracin',
    'install_header' => 'Plugin de Instalar/Desinstalar ',
    'installed' => 'Se ha instalado el Plugin',
    'uninstalled' => 'No se ha instalado el Plugin',
    'install_success' => 'Se ha instalado con xito',
    'install_failed' => 'Instalacin Fallida -- Lee tu registro de errores para averiguar por qu.',
    'uninstall_msg' => 'Se ha desinstalado el Plugin con xito',
    'install' => 'Instalar',
    'uninstall' => 'Desinstalar',
    'warning' => 'Aviso! El Plugin est an habilitado',
    'enabled' => 'Deshabilite el plugin antes de desinstalar.',
    'readme' => 'DETENTE! Antes de pulsar sobre instalar, por favor lee el ',
    'installdoc' => 'Documento de Instalacin.',
    'spamdeleted' => 'Comentario de Spam borrado',
    'foundspam' => 'Encontrado comentario de Spam coincidente ',
    'foundspam2' => ' enviado por el usuario ',
    'foundspam3' => ' desde el IP ',
    'deletespam' => 'Borrar Spam',
    'numtocheck' => 'Nmero de Comentarios a comprobar',
    'note1' => '<p>Nota: Borrado masivo est para ayudarte cuando te avasalla ',
    'note2' => ' comentarios de spam y Spam-X no lo pilla.  <ul><li>Primero, encuentra el/los enlace/s u otros ',
    'note3' => 'identificadores de este comentario de Spam y lo aades a tu lista negra personal.</li><li>Despus ',
    'note4' => 'vuelve aqu y haz que Spam-X compruebe los ltimos comentarios de spam.</li></ul><p>Los comentarios ',
    'note5' => 'se comprueban desde los ms nuevos hasta los ms antiguos -- La comprobacin de ms comentarios ',
    'note6' => 'requiere ms tiempo para llevarse a cabo</p>',
    'masshead' => '<hr' . XHTML . '><center><h1>Borrado Masivo de Comentarios Spam</h1></center>',
    'masstb' => '<hr' . XHTML . '><h1 align="center">Mass Delete Trackback Spam</h1>',
    'comdel' => ' comentarios borrados.',
    'initial_Pimport' => '<p>Importar la Lista Negra Personal"',
    'initial_import' => 'Importar la lista Negra-MT inicial',
    'import_success' => '<p>Se ha importado con xito los datos de la Lista Negra de %d.',
    'import_failure' => '<p><strong>Error:</strong> No se han encontrado datos.',
    'allow_url_fopen' => '<p>Lo sentimos, la configuracin de tu servidor de web no permite la lectura de ficheros remotos (<code>allow_url_fopen</code> is off). Por favor, descarga la Lista Negra desde el siguiente URL y sbelo al directorio de "datos" de Geeklog\'s, <tt>%s</tt>, antes de intentarlo de nuevo:',
    'documentation' => 'Documentacin del Plugin de Spam-X',
    'emailmsg' => "Un nuevo comentario de spam ha sido enviado en/desde \"%s\"\nUser UID:\"%s\"\n\nContent:\"%s\"",
    'emailsubject' => 'Spam post at %s',
    'ipblack' => 'Spam-X IP Blacklist',
    'ipofurlblack' => 'Spam-X IP of URL Blacklist',
    'headerblack' => 'Spam-X HTTP Header Blacklist',
    'headers' => 'Request headers:',
    'stats_headline' => 'Spam-X Statistics',
    'stats_page_title' => 'Blacklist',
    'stats_entries' => 'Entries',
    'stats_mtblacklist' => 'MT-Blacklist',
    'stats_pblacklist' => 'Personal Blacklist',
    'stats_ip' => 'Blocked IPs',
    'stats_ipofurl' => 'Blocked by IP of URL',
    'stats_header' => 'HTTP headers',
    'stats_deleted' => 'Posts deleted as spam',
    'plugin_name' => 'Spam-X',
    'slvwhitelist' => 'SLV Whitelist'
);

// Define Messages that are shown when Spam-X module action is taken
$PLG_spamx_MESSAGE128 = 'Se ha detectado spam y se ha borrado el Comentario o el Mensaje.';
$PLG_spamx_MESSAGE8 = 'Se ha detectado spam. Se ha enviado un correo al administrador.';

// Messages for the plugin upgrade
$PLG_spamx_MESSAGE3001 = 'Plugin upgrade not supported.';
$PLG_spamx_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['spamx'] = array(
    'label' => 'Spam-X',
    'title' => 'Spam-X Configuration'
);

$LANG_confignames['spamx'] = array(
    'spamx_action' => 'Spam-X Actions',
    'notification_email' => 'Notification Email',
    'logging' => 'Enable Logging',
    'timeout' => 'Timeout'
);

$LANG_configsubgroups['spamx'] = array(
    'sg_main' => 'Main Settings'
);

$LANG_tab['spamx'] = array(
    'tab_main' => 'Spam-X Main Settings'
);

$LANG_fs['spamx'] = array(
    'fs_main' => 'Spam-X Main Settings'
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['spamx'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false)
);

?>

==> geeklog-2.0.0-jp-extended-1.0.zip: geeklog-2.0.0-jp-extended-1.0/plugins/spamx/language/spanish.php <==
<?php

/**
 * File: spanish.php
 * This is the Spanish language page for the Geeklog Spam-X Plug-in!
 * 
 * Copyright (C) 2004-2005 by the following authors:
 * Author        Tom Willett        tomw AT pigstye DOT net
 * 
 * Licensed under GNU General Public License
 *
 * $Id: spanish.php,v 1.9 2008/05/02 15:08:10 dhaun Exp $
 */

global $LANG32;

$LANG_SX00 = array(
    'inst1' => '<p>Si haces esto, los dems ',
    'inst2' => 'podrn ver e importar tu lista negra personal y nosotros podemos crear una base de datos ',
    'inst3' => 'distribuida ms eficaz.</p><p>Si has registrado tu sitio web y decides que no deseas permanecer en la lista ',
    'inst4' => 'enva un correo electrnico a <a href="mailto:spamx@pigstye.net">spamx@pigstye.net</a> para comunicrmelo. ',
    'inst5' => 'Todas las peticiones sern respetadas.',
    'submit' => 'Enviar',
    'subthis' => 'esta informacin a la base de datos de Spam-X Central Database',
    'secbut' => 'Este botn segundo crea una fuente rdf para que otras personas puedan importar tu lista.',
    'sitename' => 'Nombre del Sitio: ',
    'URL' => 'URL a la lista de Spam-X: ',
    'RDF' => 'RDF url: ',
    'impinst1a' => 'Antes de usar la caracterstica de bloqueo de Spam con el comentario de Spam-X para ver e importar Listas negras personales de otros ',
    'impinst1b' => ' sitios, te pido que pulses sobre los siguientes dos botones. (Tienes que pulsar sobre el ltimo.)',
    'impinst2' => 'Este primero enva tu sitio web al sitio Gplugs/Spam-X para que pueda aadirse al listado principal de ',
    'impinst2a' => 'sitios que comparten sus listas negras. (Nota: Si tienes varios sitios puede que te interese designar uno de ellos como el ',
    'impinst2b' => 'principal y slo  incluir su nombre. Esto te permitir actualizar tus sitios con facilidad y mantener una lista ms pequea.) ',
    'impinst2c' => 'Despus de pulsar sobre el botn de Enviar, pulsa sobre [atrs]en tu navegador para volver aqu.',
    'impinst3' => 'Se enviarn los siguientes valores: (puedes editarlos si estn equivocados).',
    'availb' => 'Listas Negras Disponibles',
    'clickv' => 'Cliquea para ver la Lista Negra',
    'clicki' => 'Cliquea para Importar la Lista Negra',
    'ok' => 'OK',
    'rsscreated' => 'Se cre la fuente RSS',
    'add1' => 'Se han Aadido ',
    'add2' => ' datos desde ',
    'add3' => 'la lista negra de  .',
    'adminc' => 'Comandos de Administracin:',
    'mblack' => 'Mi Lista Negra:',
    'rlinks' => 'Enlaces Relacionados:',
    'e3' => 'Para aadir las palabras desde la lista de palabras censuradas de Geeklogs CensorList Pulsa el Botn:',
    'addcen' => 'Aadir Lista de Palabras Censuradas',
    'addentry' => 'Aadir dato',
    'e1' => 'Para Borrar el dato cliqualo.',
    'e2' => 'Para Aadir un dato, introdcelo en la caja y pulsa sobre Aadir.  Los datos pueden presentarse con Expresiones Normales de Perl.',
    'pblack' => 'Lista Negra Personal de Spam-X',
    'sfseblack' => 'Spam-X SFS Email Blacklist',
    'conmod' => 'Configurar el uso del mdulo de Spam-X',
    'acmod' => 'Mdulos de Accin de Spam-X',
    'exmod' => 'Mdulos de Examen de Spam-X',
    'actmod' => 'Mdulos Activos',
    'avmod' => 'Mdulos Disponibles',
    'coninst' => '<hr' . XHTML . '>Cliquea sobre un Mdulo Activo para borrarlo, cliquea sobre un mdulo Disponible para aadirlo.<br' . XHTML . '>Los mdulos se ejecutan en el orden en que han sido presentados.',
    'fsc' => 'Encontrado un comentario de Spam coincidente',
    'fsc1' => ' enviado por el usuario ',
    'fsc2' => ' desde el IP ',
    'uMTlist' => 'Actualizar la Lista Negra-MT',
    'uMTlist2' => ': Aadidas ',
    'uMTlist3' => ' entradas y borradas ',
    'entries' => ' entradas.',
    'uPlist' => 'Actualizar la Lista Negra Personal',
    'entriesadded' => 'Entradas Aadidas',
    'entriesdeleted' => 'Entradas Borradas',
    'viewlog' => 'Ver el registro de Spam-X',
    'clearlog' => 'Limpiar el fichero de Registros',
    'logcleared' => '- Fichero de Registros limpiado',
    'plugin' => 'Plugin',
    'access_denied' => 'Acceso Denegado',
    'access_denied_msg' => 'Slo los Usuarios Raz tiene Acceso a esta pgina.  Tu nombre de usuario y direccin IP han sido registrados.',
    'admin' => 'Plugin de Administracin',
    'install_header' => 'Plugin de Instalar/Desinstalar ',
    'installed' => 'Se ha instalado el Plugin',
    'uninstalled' => 'No se ha instalado el Plugin',
    'install_success' => 'Se ha instalado con xito',
    'install_failed' => 'Instalacin Fallida -- Lee tu registro de errores para averiguar por qu.',
    'uninstall_msg' => 'Se ha desinstalado el Plugin con xito',
    'install' => 'Instalar',
    'uninstall' => 'Desinstalar',
    'warning' => 'Aviso! El Plugin est an habilitado',
    'enabled' => 'Deshabilite el plugin antes de desinstalar.',
    'readme' => 'DETENTE! Antes de pulsar sobre instalar, por favor lee el ',
    'installdoc' => 'Documento de Instalacin.',
    'spamdeleted' => 'Comentario de Spam borrado',
    'foundspam' => 'Encontrado comentario de Spam coincidente ',
    'foundspam2' => ' enviado por el usuario ',
    'foundspam3' => ' desde el IP ',
    'deletespam' => 'Borrar Spam',
    'numtocheck' => 'Nmero de Comentarios a comprobar',
    'note1' => '<p>Nota: Borrado masivo est para ayudarte cuando te avasalla ',
    'note2' => ' comentarios de spam y Spam-X no lo pilla.  <ul><li>Primero, encuentra el/los enlace/s u otros ',
    'note3' => 'identificadores de este comentario de Spam y lo aades a tu lista negra personal.</li><li>Despus ',
    'note4' => 'vuelve aqu y haz que Spam-X compruebe los ltimos comentarios de spam.</li></ul><p>Los comentarios ',
    'note5' => 'se comprueban desde los ms nuevos hasta los ms antiguos -- La comprobacin de ms comentarios ',
    'note6' => 'requiere ms tiempo para llevarse a cabo</p>',
    'masshead' => '<hr' . XHTML . '><center><h1>Borrado Masivo de Comentarios Spam</h1></center>',
    'masstb' => '<hr' . XHTML . '><h1 align="center">Mass Delete Trackback Spam</h1>',
    'comdel' => ' comentarios borrados.',
    'initial_Pimport' => '<p>Importar la Lista Negra Personal"',
    'initial_import' => 'Importar la lista Negra-MT inicial',
    'import_success' => '<p>Se ha importado con xito los datos de la Lista Negra de %d.',
    'import_failure' => '<p><strong>Error:</strong> No se han encontrado datos.',
    'allow_url_fopen' => '<p>Lo sentimos, la configuracin de tu servidor de web no permite la lectura de ficheros remotos (<code>allow_url_fopen</code> is off). Por favor, descarga la Lista Negra desde el siguiente URL y sbelo al directorio de "datos" de Geeklog\'s, <tt>%s</tt>, antes de intentarlo de nuevo:',
    'documentation' => 'Documentacin del Plugin de Spam-X',
    'emailmsg' => "Un nuevo comentario de spam ha sido enviado en/desde \"%s\"\nUser UID:\"%s\"\n\nContent:\"%s\"",
    'emailsubject' => 'Spam post at %s',
    'ipblack' => 'Spam-X IP Blacklist',
    'ipofurlblack' => 'Spam-X IP of URL Blacklist',
    'headerblack' => 'Spam-X HTTP Header Blacklist',
    'headers' => 'Request headers:',
    'stats_headline' => 'Spam-X Statistics',
    'stats_page_title' => 'Blacklist',
    'stats_entries' => 'Entries',
    'stats_mtblacklist' => 'MT-Blacklist',
    'stats_pblacklist' => 'Personal Blacklist',
    'stats_ip' => 'Blocked IPs',
    'stats_ipofurl' => 'Blocked by IP of URL',
    'stats_header' => 'HTTP headers',
    'stats_deleted' => 'Posts deleted as spam',
    'invalid_email_or_ip' => 'Invalid e-mail address or IP address has been blocked.',
    'email_ip_spam' => '%s or %s attempted to register but was considered a spammer.',
    'edit_personal_blacklist' => 'Edit Personal Blacklist',
    'mass_delete_spam_comments' => 'Mass Delete Spam Comments',
    'mass_delete_trackback_spam' => 'Mass Delete Trackback Spam',
    'edit_http_header_blacklist' => 'Edit HTTP Header Blacklist',
    'edit_ip_blacklist' => 'Edit IP Blacklist',
    'edit_ip_url_blacklist' => 'Edit IP of URL Blacklist',
    'edit_sfs_blacklist' => 'Edit SFS Email Blacklist',
    'edit_slv_whitelist' => 'Edit SLV Whitelist',
    'plugin_name' => 'Spam-X',
    'slvwhitelist' => 'SLV Whitelist'
);

// Define Messages that are shown when Spam-X module action is taken
$PLG_spamx_MESSAGE128 = 'Se ha detectado spam y se ha borrado el Comentario o el Mensaje.';
$PLG_spamx_MESSAGE8 = 'Se ha detectado spam. Se ha enviado un correo al administrador.';

// Messages for the plugin upgrade
$PLG_spamx_MESSAGE3001 = 'Plugin upgrade not supported.';
$PLG_spamx_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['spamx'] = array(
    'label' => 'Spam-X',
    'title' => 'Spam-X Configuration'
);

$LANG_confignames['spamx'] = array(
    'spamx_action' => 'Spam-X Actions',
    'notification_email' => 'Notification Email',
    'logging' => 'Enable Logging',
    'timeout' => 'Timeout',
    'sfs_enabled' => 'Enable SFS',
    'snl_enabled' => 'Enable SNL',
    'snl_num_links' => 'Number of links'
);

$LANG_configsubgroups['spamx'] = array(
    'sg_main' => 'Main Settings'
);

$LANG_tab['spamx'] = array(
    'tab_main' => 'Spam-X Main Settings',
    'tab_modules' => 'Modules'
);

$LANG_fs['spamx'] = array(
    'fs_main' => 'Spam-X Main Settings',
    'fs_sfs' => 'Stop Forum Spam (SFS)',
    'fs_snl' => 'Spam Number of Links (SNL)'
);

// Note: entries 0, 1, 9, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['spamx'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false)
);

?>
